@@ -1,9 +1,11 @@
 """Top-level package for SQL Query Tools."""
 
+from . import _version
+__version__ = _version.get_versions()['version']
+
+
 __author__ = """Andoni Sooklaris"""
 __email__ = 'andoni.sooklaris@gmail.com'
-__version__ = '0.1.0'
-
 
 import csv
 import logging
@@ -13,7 +15,7 @@ import pathlib
 import sqlalchemy
 import typing
 from tqdm import tqdm
-from .utils import logger_setup, test_value, ensurelist, systime, find_binary, syscmd, listfiles
+from .utils import logger_setup, assert_value_dtype, ensurelist, systime, find_binary, syscmd, listfiles
 
 
 logger = logger_setup(name='sql-query-tools', level=logging.WARNING)
@@ -335,7 +337,7 @@ class Postgres(object):
 
             if str(val).lower() in self.null_equivalents:
                 val = 'NULL'
-            elif test_value(val, 'bool') or test_value(val, 'int') or test_value(val, 'float'):
+            elif assert_value_dtype(val, 'bool') or assert_value_dtype(val, 'int') or assert_value_dtype(val, 'float'):
                 pass
             else:
                 # Assume string
@@ -402,7 +404,7 @@ class Postgres(object):
             if str(val).lower() in self.null_equivalents:
                 val = 'null'
 
-            elif test_value(val, 'bool') or test_value(val, 'int') or test_value(val, 'float'):
+            elif assert_value_dtype(val, 'bool') or assert_value_dtype(val, 'int') or assert_value_dtype(val, 'float'):
                 pass
             else:
                 # Assume string, handle quotes
@@ -504,14 +506,14 @@ class Postgres(object):
            statement TEXT;
         BEGIN
         FOR tables IN
-           SELECT (table_schema || '.' || table_name) AS schema_table
+           SELECT ('"' || table_schema || '"' || '.' || '"' || table_name || '"') AS schema_table
            FROM information_schema.tables t
                INNER JOIN information_schema.schemata s ON s.schema_name = t.table_schema
            WHERE t.table_schema NOT IN ('pg_catalog', 'information_schema')
                AND t.table_type NOT IN ('VIEW')
            ORDER BY schema_table
         LOOP
-           statement := 'COPY ' || tables.schema_table || ' TO ''' || path || '/' || tables.schema_table || '.tmpcsv' ||''' DELIMITER ''{sep}'' CSV HEADER';
+           statement := 'COPY ' || tables.schema_table || ' TO ''' || path || '/' || replace(tables.schema_table, '"', '') || '.csv' ||''' DELIMITER ''{sep}'' CSV HEADER';
            EXECUTE statement;
         END LOOP;
         RETURN;
@@ -587,7 +589,7 @@ class Postgres(object):
         """
         Drop then re-create a Postgres schema
         """
-        args = dict(table_scham=schema_name, if_exists=if_exists, cascade=cascade)
+        args = dict(schema_name=schema_name, if_exists=if_exists, cascade=cascade)
         self.drop_schema(**args)
         self.create_schema(schema_name)
 
@@ -737,6 +739,3 @@ class Postgres(object):
             val = "'" + val + "'"
 
         return val
-
-from . import _version
-__version__ = _version.get_versions()['version']
